@@ -62,51 +62,6 @@ delete.intercept <- function (mm)
 
 
 
-# and a summary function which adjusts the summary.lm for the fixed effects
-# obsolete?  Computations included in print.lm.fe.  That's not perhaps not the R-ish way
-summary.felmfoo <- function(object,...) {
-  # call summary.lm
-  class(object) <- 'lm'
-  z <- summary.lm(object,...)
-  class(z) <- c('summary.felm',class(z))
-
-  fe <- object$fe
-  # total number of dummies
-  # subtract one reference for each connection component
-  # also, we've fiddled with the intercept, so we must
-  # adjust for that one too
-  conncomp <- nlevels(object$cfactor)
-  numdum <- sum(unlist(lapply(fe,nlevels))) - conncomp
-  # adjust the degrees of freedom, and sigma
-  
-  # degrees of freedom
-  oldrdf <- z$df[2]
-  z$df[1] <- z$df[1] + numdum
-  z$df[2] <- z$df[2] - numdum
-  z$df[3] <- z$df[3] + numdum
-  rdf <- z$df[2]
-
-
-  sefactor <- sqrt(oldrdf/rdf) 
-  # standard errors
-
-  z$coefficients[,2] <- z$coefficients[,2] * sefactor
-  tval <- z$coefficients[,3]
-  tval <- tval / sefactor
-  pval <- 2*pt(abs(tval), rdf, lower.tail=FALSE)
-  z$coefficients[,3] <- tval
-  z$coefficients[,4] <- pval
-    
-  z$adj.r.squared <- 1-(1-z$adj.r.squared)*oldrdf/rdf
-
-  z$fstatistic[1] <- z$fstatistic[1]*oldrdf/rdf
-  z$fstatistic[2] <- z$fstatistic[2] + numdum
-  z$fstatistic[3] <- rdf
- 
-  z$sigma <- z$sigma * sefactor
-  return(z)
-}
-
 
 # it seems the foreach-stuff with doMC creates memory problems
 # Even though it forks the process and relies on copy-on-write
@@ -139,7 +94,8 @@ findfe <- function(dd,Rhs) {
     if(grepl('problem too large',geterrmessage())) {
       message(paste('Never mind, trying *slower* non-supernodal algorithm, nnz=',nnzero(dd)))
       message(paste(date(),'This may be an opportunity for a nice cup of tea. Or two.'))
-      ch <- Cholesky(dd,super=FALSE,perm=FALSE)
+      gc()
+      ch <- Cholesky(dd,super=FALSE,perm=TRUE)
       trysolve <- solve(ch,Rhs)
       rm(ch)
       gc()
@@ -324,7 +280,7 @@ felm <- function(model,fl,data) {
   if(ncov == 0) {
     # No covariates
     z <- list(residuals=y,fe=fl,p=0,cfactor=compfactor(fl))
-    class(z) <- 'lm.fe'
+    class(z) <- 'felm'
     return(z)
   }
   # here we need to demean things
@@ -357,7 +313,7 @@ felm <- function(model,fl,data) {
   b <- crossprod(xz,yz)
 
   if(is.null(badvars)) {
-    beta <- backsolve(ch,backsolve(ch,b,transpose=TRUE))
+    beta <- as.vector(backsolve(ch,backsolve(ch,b,transpose=TRUE)))
     inv <- chol2inv(ch)
   } else {
     beta <- rep(NaN,nrow(cp))
@@ -366,7 +322,6 @@ felm <- function(model,fl,data) {
     inv[-badvars,-badvars] <- chol2inv(ch)
   }
   rm(b)
-
   if(icpt > 0) names(beta) <- colnames(x)[-icpt] else names(beta) <- colnames(x)
   z <- list(coefficients=beta,vcv=inv)
   N <- nrow(xz)
@@ -410,63 +365,15 @@ felm <- function(model,fl,data) {
   z$N <- N
   z$p <- p + numdum
   z$call <- match.call()
-  class(z) <- 'lm.fe'
+  class(z) <- 'felm'
 
   return(z)
 }
 
-print.lm.fe <- function(x,digits=max(3,getOption('digits')-3),...) {
-  z <- x
-  if(z$p == 0) {
-    cat('(No coefficients)\n')
-    return()
-  }
-  ans <- z[c('call','terms')]
-  ans$residuals <- z$full.residuals
-  rdf <- z$df
-  ans$coefficients <- cbind(z$coefficients,z$se,z$tval,z$pval)
-  dimnames(ans$coefficients) <- list(names(z$coefficients),
-                                     c('Estimate','Std. Error','t value','Pr(>|t|)'))
-  cat('\nCall:\n  ',deparse(z$call),'\n\n')
-  cat('Residuals:\n')
-  qres <- quantile(ans$residuals)
-  names(qres) <- c("Min", "1Q", "Median", "3Q", "Max")
-  print(qres,digits=digits)
-
-  cat('\nCoefficients:\n')
-  printCoefmat(ans$coefficients,digits=digits)
-
-
-  # compute
-  # residual se, df
-  # mrsq, adj rsq
-  # fstat, p-value
-  p <- z$p
-  rdf <- z$N - p
-  rss <- sum(z$full.residuals^2)
-  f <- z$fitted
-  resvar <- rss/rdf
-  sigma <- sqrt(resvar)
-#  mss <- sum( (f - mean(f))^2)
-  mss <- sum(f^2)
-  r2 <- mss/(mss+rss)
-  r2adj <- 1-(1-r2)*(z$N/rdf)
-  fstat <- (mss/p)/resvar
-#  z <- list(call=z$call,residuals=z$full.residuals,
-#            df=z$df)
-  pval <- pf(fstat,p,rdf,lower.tail=FALSE)
-  cat('\nResidual standard error:',format(signif(sigma,digits)),'on',rdf,'degrees of freedom\n')
-  cat('Multiple R-squared:',formatC(r2,digits=digits),'  Adjusted R-squared:',
-      formatC(r2adj,digits=digits),'\n')
-  cat('F-statistic:',formatC(fstat,digits=digits),'on',p,'and',rdf,'DF, p-value:',format.pval(pval,digits=digits),'\n')
-  if(length(z$fe) > 2)
-    cat('*** Standard errors are slightly too high due to more than 2 groups\n')
-  cat('\n\n')
-}
 
 
 # return a data-frame with the group fixed effects, including zeros for references
-getfe <- function(obj,data) {
+getfe <- function(obj) {
 
   R <- obj$residuals
   # then the remaining.  This is usually sufficient.
