@@ -20,7 +20,7 @@ dset <- data.frame(y,x,x2,id,firm)
 
 ## estimate and print result
 est <- felm(y ~ x+x2,fl=list(id=id,firm=firm),data=dset)
-print(est)
+summary(est)
 
-## extract the group fixed effects, and print them
-print(getfe(est))
+## extract the group fixed effects
+getfe(est)
